@@ -42,8 +42,15 @@ def run() :
     parser.add_argument("--suite", metavar='Suite_Name', action='append', help="套件名过滤，支持通配符", default=[])
     parser.add_argument("--tag", metavar='Tag_Expression', action='append', help="标签名过滤，支持通配符", default=[])
     parser.add_argument("--tagnot", metavar='Tag_Expression', action='append', help="标签名过滤，支持通配符", default=[])
+    parser.add_argument("-A", "--argfile", metavar='Argument_File', help="参数文件", type=argparse.FileType('r', encoding='utf8'))
 
-    args =  parser.parse_args()
+
+    args = parser.parse_args()
+    # 有参数放在文件中
+    if args.argfile:
+        fileArgs = [para for para in args.argfile.read().replace('\n',' ').split() if para]
+        print(fileArgs)
+        args = parser.parse_args(fileArgs,args)
 
     LogLevel.level = args.loglevel
     # print('loglevel',LogLevel.level)
